@@ -11,8 +11,7 @@ use tokio::io;
 
 #[tokio::main]
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
-    let stdout = io::stdout();
-    let mut writer = vcf::AsyncWriter::new(stdout);
+    let mut writer = vcf::AsyncWriter::new(io::stdout());
 
     let header = vcf::Header::builder()
         .add_contig(Contig::new(String::from("sq0")))
