@@ -6,7 +6,7 @@ pub mod chromosome;
 mod field;
 pub mod filters;
 pub mod format;
-pub mod genotype;
+pub mod genotypes;
 pub mod ids;
 pub mod info;
 pub mod position;
@@ -16,10 +16,16 @@ pub(crate) mod value;
 
 pub use self::{
     alternate_bases::AlternateBases, builder::Builder, chromosome::Chromosome, field::Field,
-    filters::Filters, format::Format, genotype::Genotype, ids::Ids, info::Info, position::Position,
-    quality_score::QualityScore, reference_bases::ReferenceBases,
+    filters::Filters, format::Format, genotypes::Genotypes, ids::Ids, info::Info,
+    position::Position, quality_score::QualityScore, reference_bases::ReferenceBases,
 };
 
+#[deprecated(
+    since = "0.8.0",
+    note = "Use `noodles_vcf::record::genotypes::{genotype, Genotype}` instead."
+)]
+pub use self::genotypes::{genotype, Genotype};
+
 use std::{convert::TryFrom, error, fmt, num, str::FromStr};
 
 pub(crate) const MISSING_FIELD: &str = ".";
@@ -44,7 +50,7 @@ pub struct Record {
     filters: Filters,
     info: Info,
     format: Option<Format>,
-    genotypes: Vec<Genotype>,
+    genotypes: Genotypes,
 }
 
 impl Record {
@@ -281,7 +287,11 @@ impl Record {
     /// # use std::convert::TryFrom;
     /// use noodles_vcf::{
     ///     self as vcf,
-    ///     record::{genotype::field::Key, Format, Genotype, Position},
+    ///     record::{
+    ///         genotypes::{genotype::field::Key, Genotype},
+    ///         Format,
+    ///         Position,
+    ///     },
     /// };
     ///
     /// let format: Format = "GT:GQ".parse()?;
@@ -312,7 +322,11 @@ impl Record {
     /// # use std::convert::TryFrom;
     /// use noodles_vcf::{
     ///     self as vcf,
-    ///     record::{genotype::{field::{Key, Value}, Field}, Format, Genotype, Position},
+    ///     record::{
+    ///         genotypes::{genotype::{field::{Key, Value}, Field}, Genotype},
+    ///         Format,
+    ///         Position,
+    ///     },
     /// };
     ///
     /// let format: Format = "GT:GQ".parse()?;
@@ -325,15 +339,17 @@ impl Record {
     ///     .add_genotype(Genotype::from_str_format("0|0:13", &format)?)
     ///     .build()?;
     ///
-    /// assert_eq!(record.genotypes(), [
+    /// let expected = vec![
     ///     Genotype::try_from(vec![
     ///         Field::new(Key::Genotype, Some(Value::String(String::from("0|0")))),
     ///         Field::new(Key::ConditionalGenotypeQuality, Some(Value::Integer(13))),
-    ///     ])?,
-    /// ]);
+    ///     ])?
+    /// ].into();
+    ///
+    /// assert_eq!(record.genotypes(), &expected);
     /// # Ok::<(), Box<dyn std::error::Error>>(())
     /// ```
-    pub fn genotypes(&self) -> &[Genotype] {
+    pub fn genotypes(&self) -> &Genotypes {
         &self.genotypes
     }
 }
@@ -453,10 +469,7 @@ impl fmt::Display for Record {
 
         if let Some(format) = self.format() {
             write!(f, "\t{}", format)?;
-
-            for field in self.genotypes() {
-                write!(f, "\t{}", field)?;
-            }
+            write!(f, "\t{}", self.genotypes())?;
         }
 
         Ok(())
@@ -487,7 +500,7 @@ pub enum ParseError {
     /// The format is invalid.
     InvalidFormat(format::ParseError),
     /// A genotype is invalid.
-    InvalidGenotype(genotype::ParseError),
+    InvalidGenotype(genotypes::genotype::ParseError),
 }
 
 impl error::Error for ParseError {}
@@ -549,11 +562,12 @@ impl FromStr for Record {
             .as_ref()
             .map(|f| {
                 fields
-                    .map(|s| Genotype::from_str_format(s, f))
+                    .map(|s| genotypes::Genotype::from_str_format(s, f))
                     .collect::<Result<_, _>>()
                     .map_err(ParseError::InvalidGenotype)
             })
-            .unwrap_or_else(|| Ok(Vec::new()))?;
+            .unwrap_or_else(|| Ok(Vec::new()))?
+            .into();
 
         Ok(Self {
             chromosome: chrom,
@@ -626,6 +640,8 @@ mod tests {
 
     #[test]
     fn test_fmt_with_format() -> Result<(), Box<dyn std::error::Error>> {
+        use genotypes::Genotype;
+
         let format: Format = "GT:GQ".parse()?;
 
         let record = Record::builder()
@@ -677,6 +693,8 @@ mod tests {
 
     #[test]
     fn test_from_str_with_genotype_info() -> Result<(), Box<dyn std::error::Error>> {
+        use genotypes::genotype;
+
         let s = "chr1\t13\tnd0\tATCG\tA\t5.8\tPASS\tSVTYPE=DEL\tGT:GQ\t0|1:13";
         let record: Record = s.parse()?;
 
