@@ -31,7 +31,7 @@ impl fmt::Display for Info {
         } else {
             for (i, field) in self.values().enumerate() {
                 if i > 0 {
-                    write!(f, "{}", DELIMITER)?
+                    write!(f, "{}", DELIMITER)?;
                 }
 
                 write!(f, "{}", field)?;
